@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: main_header.php,v 1.64 2011/12/14 16:12:43 gruberroland Exp $
+$Id: main_header.php,v 1.67 2012/08/18 15:53:52 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2011  Roland Gruber
@@ -75,6 +75,7 @@ foreach ($jsFiles as $jsEntry) {
 
 // get tool list
 $availableTools = getTools();
+$toolSettings = $_SESSION['config']->getToolSettings();
 // sort tools
 $toSort = array();
 for ($i = 0; $i < sizeof($availableTools); $i++) {
@@ -89,6 +90,10 @@ for ($i = 0; $i < sizeof($availableTools); $i++) {
 	if (!$myTool->isVisible()) {
 		continue;
 	}
+	// check if hidden by config
+	if (isset($toolSettings['tool_hide_' . get_class($myTool)]) && ($toolSettings['tool_hide_' . get_class($myTool)] == 'true')) {
+		continue;
+	}
 	$toSort[$availableTools[$i]] = $myTool->getPosition();
 }
 asort($toSort);
@@ -117,18 +122,19 @@ foreach ($toSort as $key => $value) {
 		</td>
 	<td align="right" height=30>
 	<ul id="dropmenu" class="dropmenu">
-		<li><a href="<?php echo $headerPrefix; ?>logout.php" target="_top"><img height="16" width="16" alt="logout" src="<?php echo $headerPrefix; ?>../graphics/exit.png">&nbsp;<?php echo _("Logout") ?></a></li>
+		<li><a href="<?php echo $headerPrefix; ?>logout.php" target="_top"><img class="align-middle" height="16" width="16" alt="logout" src="<?php echo $headerPrefix; ?>../graphics/exit.png">&nbsp;<?php echo _("Logout") ?></a></li>
 		<?php
 		if (is_dir(dirname(__FILE__) . '/../docs/manual')) {
 		?>
 	    <li>
-			<a target="_blank" href="<?php echo $headerPrefix; ?>../docs/manual/index.html"><img width="16" height="16" alt="help" src="<?php echo $headerPrefix; ?>../graphics/help.png">&nbsp;<?php echo _("Help") ?>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</a>
+			<a target="_blank" href="<?php echo $headerPrefix; ?>../docs/manual/index.html"><img class="align-middle" width="16" height="16" alt="help" src="<?php echo $headerPrefix; ?>../graphics/help.png">&nbsp;<?php echo _("Help") ?>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</a>
 		</li>
 		<?php
 		}
+		if (sizeof($tools) > 0) {
 		?>
 		<li>
-			<a href="<?php echo $headerPrefix; ?>tools.php"><img height="16" width="16" alt="tools" src="<?php echo $headerPrefix; ?>../graphics/tools.png">&nbsp;<?php echo _("Tools") ?></a>
+			<a href="<?php echo $headerPrefix; ?>tools.php"><img class="align-middle" height="16" width="16" alt="tools" src="<?php echo $headerPrefix; ?>../graphics/tools.png">&nbsp;<?php echo _("Tools") ?></a>
 				<ul>
 				<?php
 					for ($i = 0; $i < sizeof($tools); $i++) {
@@ -155,10 +161,11 @@ foreach ($toSort as $key => $value) {
 			</ul>
 		</li>
 		<?php
+		}
 		if ($_SESSION['config']->get_Suffix('tree') != "") {
 		?>
 	    <li>
-			<a href="<?php echo $headerPrefix; ?>tree/treeViewContainer.php"><img height="16" width="16" alt="tree" src="<?php echo $headerPrefix; ?>../graphics/process.png">&nbsp;<?php echo _("Tree view") ?></a>
+			<a href="<?php echo $headerPrefix; ?>tree/treeViewContainer.php"><img class="align-middle" height="16" width="16" alt="tree" src="<?php echo $headerPrefix; ?>../graphics/process.png">&nbsp;<?php echo _("Tree view") ?></a>
 		</li>
 		<?php
 		}
