@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: massBuildAccounts.php,v 1.27 2012/03/18 18:24:25 gruberroland Exp $
+$Id: massBuildAccounts.php,v 1.28 2012/08/13 17:43:48 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2004 - 2012  Roland Gruber
@@ -41,6 +41,9 @@ include_once('../lib/modules.inc');
 // Start session
 startSecureSession();
 
+// check if this tool may be run
+checkIfToolIsActive('toolFileUpload');
+
 // die if no write access
 if (!checkIfWriteAccessIsAllowed()) die();
 
