@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: profilepage.php,v 1.48 2011/05/14 13:51:08 gruberroland Exp $
+$Id: profilepage.php,v 1.50 2012/08/26 14:09:22 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2010  Roland Gruber
@@ -47,6 +47,8 @@ startSecureSession();
 // die if no write access
 if (!checkIfWriteAccessIsAllowed()) die();
 
+checkIfToolIsActive('toolProfileEditor');
+
 setlanguage();
 
 // check if user is logged in, if not go to login
@@ -92,6 +94,10 @@ if (isset($_POST['save'])) {
 			if (isset($_POST[$element])) $options[$element] = $_POST[$element];  // value is already an array
 			else $options[$element] = array();
 		}
+		// textareas
+		if ($_SESSION['profile_types'][$element] == "textarea") {
+			$options[$element] = explode("\r\n", $_POST[$element]);
+		}
 	}
 	
 	// remove double slashes if magic quotes are on
